# aioqs
Python 3.5+ library package providing yet another queue/schedule of asynchronous coroutines with limiting number of simultaneously running coroutines as simple to use async iterator. With no overhead on tracking worker coroutines state.
